@@ -21,9 +21,13 @@ from MergeHRISClient.api.companies_api import CompaniesApi
 from MergeHRISClient.api.employee_payroll_runs_api import EmployeePayrollRunsApi
 from MergeHRISClient.api.employees_api import EmployeesApi
 from MergeHRISClient.api.employments_api import EmploymentsApi
+from MergeHRISClient.api.generate_key_api import GenerateKeyApi
 from MergeHRISClient.api.link_token_api import LinkTokenApi
 from MergeHRISClient.api.locations_api import LocationsApi
 from MergeHRISClient.api.passthrough_api import PassthroughApi
 from MergeHRISClient.api.payroll_runs_api import PayrollRunsApi
+from MergeHRISClient.api.regenerate_key_api import RegenerateKeyApi
+from MergeHRISClient.api.sync_status_api import SyncStatusApi
 from MergeHRISClient.api.teams_api import TeamsApi
 from MergeHRISClient.api.time_off_api import TimeOffApi
+from MergeHRISClient.api.time_off_balance_api import TimeOffBalanceApi
